@@ -4,9 +4,11 @@ from lpd.metrics.categorical_accuracy import CategoricalAccuracy
 
 
 class CategoricalAccuracyWithLogits(MetricBase):
+    """
+        Same as CategoricalAccuracy, but more explicit about the Logits
+    """
     def __init__(self):
         self.ca = CategoricalAccuracy()
         
     def __call__(self, y_pred: T.Tensor, y_true: T.Tensor):
-        y_pred_softmax = T.softmax(y_pred, dim=1)
-        return self.ca(y_pred_softmax, y_true)
\ No newline at end of file
+        return self.ca(y_pred, y_true)
\ No newline at end of file
